# QCCS Monitor

The application is divided into two parts, the monitor server (aka back end)
and the monitor client (aka front end). While the monitor server is a binary
executable running on a PC, the monitor client is a web application running in
the browser. The monitor server is the interface between the LabOne data server
(and the devices to be monitored) and the visual representation displayed in
the browser.

## Monitor Server

Only a few command line arguments are required to run the monitor server. Use
`--help` to get more information about the command line arguments.

One or more configuration files or even a directory with configuration files
can be specified. For the format of the configuration files, see the section
below.

__Make sure that the binaries are executable on Linux and macOS.__

Example:

```bash
./bin/qccs-monitor-server --resdir=./res ./config/neuromancer.json
```

The monitor server is listening on port _9005_ by default and can be accessed
at http://localhost:9005/ if the browser and the monitor server are running on
the same machine. Otherwise replace _localhost_ with the computer/domain name
of the host.

__Make sure that your firewall is not blocking the used TCP port.__

By pressing Ctrl-C the monitor server is shutdown.

## Configuration File

Referring to the example below, `host` and `port` specify the LabOne data
server to use. The `slug` is the name of the system and can be used in the URL
to access the page without browsing the overview. The elements of `racks`
specify the layout (`height` and `width`) and which devices to be monitored.
Currently supported device types are: PQSC, HDAWG4, HDAWG8, UHFQA, SHFQA2,
SHFQA4, SHFSG4 and SHFSG8. Use `unknown` for every other device type (e.g.
3rd-party) or omit `devtype` and `devid` entirely for blanks.

An example configuration file showing all supported device types can be found
in the config directory (`config/example.json`). Note that the device IDs need
to be updated accordingly (i.e. replace "XXX") before starting the monitor
server.

Example:

```json
{
  "host": "localhost",
  "port": 8004,
  "slug": "neuromancer",
  "racks": [[
    { "height": 4, "width": 1,   "devtype": "unknown"                     },
    { "height": 2, "width": 1,   "devtype": "PQSC",   "devid": "dev10011" },
    { "height": 2, "width": 0.5, "devtype": "HDAWG8", "devid": "dev8217"  },
    { "height": 2, "width": 0.5, "devtype": "HDAWG8", "devid": "dev8216"  },
    { "height": 2, "width": 1,   "devtype": "UHFQA",  "devid": "dev2029"  },
    { "height": 2, "width": 1,   "devtype": "UHFQA",  "devid": "dev2043"  },
    { "height": 2, "width": 1,   "devtype": "unknown"                     },
    { "height": 2, "width": 1,   "devtype": "unknown"                     },
    { "height": 2, "width": 0.5, "devtype": "unknown"                     },
    { "height": 2, "width": 0.5                                           },
    { "height": 2, "width": 1,   "devtype": "unknown"                     },
    { "height": 5, "width": 1                                             }
  ]]
}
```
